@@ -1,6 +1,6 @@
 package Parse::Dia::SQL;
 
-# $Id: SQL.pm,v 1.53 2010/05/27 09:23:27 aff Exp $
+# $Id: SQL.pm,v 1.55 2011/02/16 10:23:11 aff Exp $
 
 =pod
 
@@ -47,6 +47,12 @@ See L<http://tedia2sql.tigris.org/usingtedia2sql.html>
 
 =item * Preliminary support for Dia's I<database> shapes is added. 
 
+=item * Table comments are used as I<table postfix options>.  This
+means per-table options (e.g. partitioning options) are supported on a
+per-database level.
+
+=item * I<backticks> notation is supported for MySQL-InnoDB.
+
 =back
 
 =head1 DIA VERSIONS
@@ -179,18 +185,19 @@ use Parse::Dia::SQL::Const;
 use Parse::Dia::SQL::Output;
 
 use Parse::Dia::SQL::Output::DB2;
-use Parse::Dia::SQL::Output::Ingres;
+use Parse::Dia::SQL::Output::HTML;
 use Parse::Dia::SQL::Output::Informix;
+use Parse::Dia::SQL::Output::Ingres;
 use Parse::Dia::SQL::Output::MySQL::InnoDB;
 use Parse::Dia::SQL::Output::MySQL::MyISAM;
 use Parse::Dia::SQL::Output::MySQL;
 use Parse::Dia::SQL::Output::Oracle;
 use Parse::Dia::SQL::Output::Postgres;
+use Parse::Dia::SQL::Output::SQLite3;
 use Parse::Dia::SQL::Output::Sas;
 use Parse::Dia::SQL::Output::Sybase;
-use Parse::Dia::SQL::Output::SQLite3;
 
-our $VERSION = '0.16_02';
+our $VERSION = '0.20_01';
 
 my $UML_ASSOCIATION  = 'UML - Association';
 my $UML_SMALLPACKAGE = 'UML - SmallPackage';
@@ -241,6 +248,9 @@ sub new {
     diaversion     => $param{diaversion} || undef,
     ignore_type_mismatch => $param{ignore_type_mismatch} || undef,
     converted            => 0,
+    loglevel    => $param{loglevel} || undef,
+    backticks   => $param{backticks} || undef,      # MySQL-InnoDB only
+    htmlformat  => $param{htmlformat} || '',        # HTML output only
   };
 
   bless($self, $class);
@@ -264,7 +274,7 @@ sub new {
 # Initialize logger
 sub _init_log {
   my $self = shift;
-  my $logger = Parse::Dia::SQL::Logger::->new();
+  my $logger = Parse::Dia::SQL::Logger::->new(loglevel => $self->{loglevel});
   $self->{log} = $logger->get_logger(__PACKAGE__);
   return 1;
 }
@@ -282,6 +292,7 @@ sub _init_utils {
   $self->{utils} = Parse::Dia::SQL::Utils::->new(
     db         => $self->{db},
     default_pk => $self->{default_pk},
+    loglevel   => $self->{loglevel},
   );
   return 1;
 }
@@ -315,7 +326,7 @@ sub get_output_instance {
   # Add some args to param unless they are set by caller
   %param =
     map { $param{$_} = $self->{$_} unless exists($param{$_}); $_ => $param{$_} }
-      qw(classes associations small_packages components files index_options typemap);
+      qw(classes associations small_packages components files index_options typemap loglevel backticks htmlformat);
 
   if ($self->{db} eq q{db2}) {
   return Parse::Dia::SQL::Output::DB2->new(%param);
@@ -337,6 +348,8 @@ sub get_output_instance {
     return Parse::Dia::SQL::Output::Sas->new(%param);
   } elsif ($self->{db} eq q{sqlite3}) {
     return Parse::Dia::SQL::Output::SQLite3->new(%param);
+  } elsif ($self->{db} eq q{html}) {
+    return Parse::Dia::SQL::Output::HTML->new(%param);
   }
 
   return $self->{log}->logdie(qq{Failed to get instance for } . $self->{db});
@@ -861,7 +874,10 @@ sub _parse_database_table {
       $self->{utils}
       ->get_value_from_object( $singleAttrib, "dia:attribute", "name", "comment",
       "string", 1 );
-    $attribComment =~ s/\n/ /g;
+
+	# Strip newlines from comments except for HTML output
+    $attribComment =~ s/\n/ /g if ($self->{db} ne q{html});
+	chomp($attribComment); # Always strip any trailing newlines
 
     $self->{log}->debug(
     "attribute: $attribName - $attribType - $attribVal - $attrib_is_primary_key"
@@ -1007,7 +1023,10 @@ sub _parse_class {
       $self->{utils}
       ->get_value_from_object( $singleAttrib, "dia:attribute", "name", "comment",
       "string", 1 );
-    $attribComment =~ s/\n/ /g;
+
+	# Strip newlines from comments except for HTML output
+    $attribComment =~ s/\n/ /g if ($self->{db} ne q{html});
+	chomp($attribComment); # Always strip any trailing newlines
 
     $self->{log}->debug(
     "attribute: $attribName - $attribType - $attribVal - $attribVisibility"
